pub struct AnalyticsDecodeError {
kind: AnalyticsDecodeErrorKind,
}Expand description
Failure to decode or validate an analytics protobuf payload.
Fields
kind: AnalyticsDecodeErrorKindImplementations
Sourceimpl AnalyticsDecodeError
impl AnalyticsDecodeError
const fn result_view(source: DecodeError) -> Self
const fn timeline_view(source: DecodeError) -> Self
const fn chunk_telemetry(source: DecodeError) -> Self
const fn missing_result_core() -> Self
Sourcepub const fn stage(&self) -> AnalyticsDecodeStage
pub const fn stage(&self) -> AnalyticsDecodeStage
Return the stage that rejected the payload.
Sourcepub const fn is_missing_result_core(&self) -> bool
pub const fn is_missing_result_core(&self) -> bool
Return whether the decoded result omitted its required core section.